@@ -19,6 +19,15 @@ require_once(__DIR__ . '/../../libs/ApiKeyManager.php');
 require_once(__DIR__ . '/../../libs/network.php');
 
 try {
+    // Store raw input early since php://input can only be read once
+    $rawRequestBody = file_get_contents('php://input');
+    
+    // Debug incoming request
+    error_log("SSO API Request - Method: " . $_SERVER['REQUEST_METHOD']);
+    error_log("SSO API Request - Headers: " . json_encode(getallheaders()));
+    error_log("SSO API Request - GET params: " . json_encode($_GET));
+    error_log("SSO API Request - Raw body: " . $rawRequestBody);
+    
     // Authenticate and check permissions
     $authData = api_authenticate('sso_access');
     
@@ -27,7 +36,7 @@ try {
     
     switch ($method) {
         case 'POST':
-            handlePostRequest($action, $authData);
+            handlePostRequest($action, $authData, $rawRequestBody);
             break;
             
         default:
@@ -39,14 +48,14 @@ try {
     api_response(false, null, 'Internal server error: ' . $e->getMessage(), 500);
 }
 
-function handlePostRequest($action, $authData) {
+function handlePostRequest($action, $authData, $rawRequestBody) {
     switch ($action) {
         case 'generate_token':
-            generateSSOToken($authData);
+            generateSSOToken($authData, $rawRequestBody);
             break;
             
         case 'validate_user':
-            validateUserForSSO();
+            validateUserForSSO($rawRequestBody);
             break;
             
         default:
@@ -54,11 +63,11 @@ function handlePostRequest($action, $authData) {
     }
 }
 
-function generateSSOToken($authData) {
-    $input = json_decode(file_get_contents('php://input'), true);
+function generateSSOToken($authData, $rawInput) {
+    $input = json_decode($rawInput, true);
     
     // Enhanced logging for debugging
-    error_log("SSO Token Request - Raw input: " . file_get_contents('php://input'));
+    error_log("SSO Token Request - Raw input: " . $rawInput);
     error_log("SSO Token Request - Parsed input: " . json_encode($input));
     
     if (!$input) {
@@ -124,8 +133,8 @@ function generateSSOToken($authData) {
     }
 }
 
-function validateUserForSSO() {
-    $input = json_decode(file_get_contents('php://input'), true);
+function validateUserForSSO($rawInput) {
+    $input = json_decode($rawInput, true);
     
     if (!$input) {
         api_response(false, null, 'Invalid JSON input', 400);
