@@ -18,6 +18,11 @@ require_once(__DIR__ . '/../../libs/api_auth.php');
 require_once(__DIR__ . '/../../libs/usermgmt.php');
 
 try {
+    // Debug incoming request for user management API
+    error_log("Users API Request - Method: " . $_SERVER['REQUEST_METHOD']);
+    error_log("Users API Request - Headers: " . json_encode(getallheaders()));
+    error_log("Users API Request - GET params: " . json_encode($_GET));
+    
     // Authenticate and check permissions
     $authData = api_authenticate('user_management');
     
