@@ -349,8 +349,10 @@ function whp_ServiceSingleSignOn(array $params) {
             'username' => $username,
             'serverdata_keys' => array_keys($serverdata),
             'hostname' => $serverdata['hostname'] ?? 'not set',
-            'api_key_set' => !empty($serverdata['username']),
-            'api_secret_set' => !empty($serverdata['password'])
+            'api_key_length' => strlen($serverdata['username'] ?? ''),
+            'api_secret_length' => strlen($serverdata['password'] ?? ''),
+            'api_key_preview' => substr($serverdata['username'] ?? '', 0, 10) . '...',
+            'api_secret_preview' => substr($serverdata['password'] ?? '', 0, 10) . '...'
         ), 'Starting SSO process');
         
         // Generate SSO token
